@@ -5,12 +5,10 @@ Created on Feb 21th, 2011
 '''
 import os
 import sys
-import time 
-import threading 
-
-from ConfigParser import ConfigParser
+import time
+import xmlrpclib
 from optparse import OptionParser, TitledHelpFormatter
-from shutil import copyfile
+from pkg_resources import parse_version, working_set
 
 from config import Environment
 from api import ScalrConnection, ScalrAPIError
@@ -920,10 +918,22 @@ class CheckUpdates(Command):
 	name = 'check-updates'
 
 	def run(self):
-		import pkg_resources
-		working_set = pkg_resources.working_set
 		versions = dict([(d.key, d.version) for d in working_set])
-		print 'Current version is: %s' % (versions['scalr'])
+		installed = versions['scalr']
+		print 'Installed version: %s' % (installed)
+
+		repo = 'http://pypi.python.org/pypi'
+		pypi = xmlrpclib.ServerProxy(repo)
+		available = pypi.package_releases('scalr')
+
+		if available:
+			latest = available[-1]
+			print 'Latest version in repo %s: %s' % (repo, latest)
+			if cmp(parse_version(installed), parse_version(latest)):
+				print 'Update available.'
+				print "You can update scalr-tools by executing 'sudo easy_install --upgrade scalr' in Linux/OSX console."
+			else:
+				print 'No updates available.'
 
 
 def waits(n):
